Introduction
------------

Chance is an event manager for Django with `Django CMS` integration for
registration forms.

Installation
------------

First, you must install `Django`. For full details, see the installation 
instructions on their website.

Install ``django-chance`` to your environment with a tool such as `PIP`, 
`setuptools`, or `buildout`.

Add ``chance`` to the ``INSTALLED_APPS`` list in your project's 
``settings.py`` and run the ``syncdb`` command on your ``manage.py``.

.. _Django: http://www.djangoproject.com/
.. _Django CMS: https://www.django-cms.org/
.. _PIP: http://www.pip-installer.org/
.. _setuptools: http://pypi.python.org/pypi/setuptools/
.. _buildout: http://pypi.python.org/pypi/zc.buildout/

What's Inside
-------------

Admin integration for creating and managing events. Views for displaying
events and managing registration.

